@@ -15,5 +15,5 @@ for lin in lins:
 lins.sort(key=lambda lin: lin.label)
 
 # and finally plot:
-lins.bode(title="Bode plot of Modelica.Blocks.Continuous.PID\n"
-                "with varying differential time constant")
+lins.bode(title=("Bode plot of Modelica.Blocks.Continuous.PID\n"
+                 "with varying differential time constant"))
