@@ -18,6 +18,12 @@ __copyright__ = ("Copyright 2012-2014, Kevin Davies, Hawaii Natural Energy "
                  "Institute, and Georgia Tech Research Corporation")
 __license__ = "BSD-compatible (see LICENSE.txt)"
 
+# Standard pylint settings for this project:
+# pylint: disable=I0011, C0302, C0325, R0903, R0904, R0912, R0913, R0914, R0915,
+# pylint: disable=I0011, W0141, W0142
+
+# Other:
+# pylint: disable=C0103, E0611, E1101, W0102
 
 import os
 import numpy as np
@@ -37,8 +43,6 @@ from modelicares._io.dymola import loadlin as dymola
 LOADERS = [('dymola', dymola)] # LinRes tries these in order.
 # All of the keys should be in lowercase.
 
-#pylint: disable=C0103, C0302, C0325, R0913, R0914, W0102, W0142
-
 def _from_names(func):
     """Return a method that accepts names or indices to identify system inputs
     and outputs, given a method that only accepts indices (*func*).
@@ -112,9 +116,6 @@ class LinRes(Res):
 
     - :meth:`bode` - Create a Bode plot of the system's response.
 
-    - :meth:`fbase` - Return the base filename from which the data was loaded,
-      without the directory or file extension.
-
     - :meth:`nyquist` - Create a Nyquist plot of the system's response.
 
     - :meth:`to_siso` - Return a SISO state-space system given input and output
@@ -124,11 +125,11 @@ class LinRes(Res):
 
     **Properties:**
 
-    - *basename* - Base filename from which the variables were loaded, without
-      the directory or extension
-
     - *dirname* - Directory from which the variables were loaded
 
+    - *fbase* - Base filename from which the variables were loaded, without
+      the directory or extension
+
     - *fname* - Filename from which the variables were loaded, with absolute
       path
 
@@ -194,7 +195,7 @@ class LinRes(Res):
 
         # Remember the tool and filename.
         self.tool = tool
-        self.fname = os.path.abspath(fname)
+        super(LinRes, self).__init__(fname)
 
     def __str__(self):
         """Return an informal description of the :class:`LinRes` instance.
@@ -546,6 +547,9 @@ class LinResList(ResList):
     - :class:`LinResList`\(*filespec1*, *filespec2*, ...): Loads all files
       matching or contained by *filespec1*, *filespec2*, etc. as above.
 
+         Each file will be opened once at most; duplicate filename matches are
+         ignored.
+
     **Built-in methods:**
 
     The entries are :class:`LinRes` instances, but linearizations can be
