@@ -31,6 +31,13 @@ __copyright__ = ("Copyright 2012-2014, Kevin Davies, Hawaii Natural Energy "
 __license__ = "BSD-compatible (see LICENSE.txt)"
 
 
+# Standard pylint settings for this project:
+# pylint: disable=I0011, C0302, C0325, R0903, R0904, R0912, R0913, R0914, R0915,
+# pylint: disable=I0011, W0141, W0142
+
+# Other:
+# pylint: disable=C0103, E0611, E1101, W0102
+
 import os
 import numpy as np
 
@@ -51,9 +58,6 @@ from modelicares import util
 from modelicares._res import Res, ResList
 from modelicares.texunit import unit2tex, number_label
 
-#pylint: disable=C0103, C0302, E0213, R0912, R0913, R0914, R0915, W0102, W0142
-
-
 def _apply_function(func):
     """Return a method that applies a function to its output, given a
     method that doesn't (*func*).
@@ -643,6 +647,7 @@ class VarList(list):
        [-1.6083468, 0.84736514]
 
     """
+    # pylint: disable=E0213
 
     def _listmethod(func):
         """Return a method that operates on all of the variables in the list of
@@ -654,6 +659,7 @@ class VarList(list):
             variable, then pass it to the function and return the result
             upwards.
             """
+            # pylint: disable=E1102
             return util.CallList([func(variable, attr)
                                   if isinstance(variable, Variable) else
                                   wrapped(variable, attr)
@@ -736,9 +742,6 @@ class SimRes(Res):
 
     **Properties:**
 
-    - *basename* - Base filename from which the variables were loaded, without
-      the directory or extension
-
     - *dirname* - Directory from which the variables were loaded
 
     - *fbase* - Base filename from which the results were loaded, without the
@@ -763,6 +766,8 @@ class SimRes(Res):
     .. _pandas DataFrame: http://pandas.pydata.org/pandas-docs/stable/generated/pandas.DataFrame.html?highlight=dataframe#pandas.DataFrame
     """
 
+    # pylint: disable=R0921
+
     def __init__(self, fname='dsres.mat', constants_only=False, tool=None):
         """Upon initialization, load Modelica_ simulation results from a file.
 
@@ -941,6 +946,7 @@ class SimRes(Res):
 
         def do_work():
             """Launch the broswer."""
+            # pylint: disable=E1101
             app = wx.GetApp()
             if app is None:
                 app = wx.App()
@@ -950,10 +956,10 @@ class SimRes(Res):
             app.MainLoop()
 
         # TODO: Fix multithreading so that the browser can run in the background.
-        #import threading
-        #thread = threading.Thread(target=_do_work)
-        #thread.setDaemon(True)
-        #thread.start()
+        # import threading
+        # thread = threading.Thread(target=_do_work)
+        # thread.setDaemon(True)
+        # thread.start()
 
         do_work()
 
@@ -1663,6 +1669,9 @@ class SimResList(ResList):
     - :class:`SimResList`\(*filespec1*, *filespec2*, ...): Loads all files
       matching or contained by *filespec1*, *filespec2*, etc. as above.
 
+         Each file will be opened once at most; duplicate filename matches are
+         ignored.
+
     **Built-in methods**
 
     The list has all of the methods
@@ -1734,7 +1743,7 @@ class SimResList(ResList):
     - *unique_names* - Return a dictionary of variable names that are not
       in all of the simulations.
 
-    - Also, the properties of :class:`SimRes` (*basename*, *dirname*, *fname*,
+    - Also, the properties of :class:`SimRes` (*dirname*, *fbase*, *fname*,
       *n_constants*, and *tool*) can be retrieve as a list across all of the
       linearizations; see the example below.
 
@@ -2120,7 +2129,7 @@ class SimResList(ResList):
           change over time
 
         - *tolerance*: Maximum variation allowed for values to still be
-          considered the same.
+          considered the same
 
         **Example:**
 
