@@ -95,11 +95,11 @@ __copyright__ = ("Copyright 2012-2014, Kevin Davies, Hawaii Natural Energy "
 __license__ = "BSD-compatible (see LICENSE.txt)"
 
 import os
-import re
 import sys
 import time
 import numpy as np
 import matplotlib.pyplot as plt
+import re as regexp
 
 from collections import MutableMapping
 from decimal import Decimal
@@ -112,11 +112,14 @@ from matplotlib import rcParams
 from matplotlib._pylab_helpers import Gcf
 from matplotlib.cbook import iterable
 from matplotlib.lines import Line2D
-from re import compile as re_compile
 from six import string_types
 
-#pylint: disable=C0302, C0103, C0302, C0325, R0904, R0912, R0913, R0914, W0102,
-#pylint: disable=W0141, W0142, W0621
+# Standard pylint settings for this project:
+# pylint: disable=I0011, C0302, C0325, R0903, R0904, R0912, R0913, R0914, R0915,
+# pylint: disable=I0011, W0141, W0142
+
+# Other:
+# pylint: disable=C0103, E1101, W0102, W0621
 
 # Load the getSaveFileName function from an available Qt installation.
 try:
@@ -258,7 +261,7 @@ def add_vlines(ax=None, positions=[0], labels=[], **kwargs):
 
     **Arguments:**
 
-    - *ax*: Axes (matplotlib.axes object)
+    - *ax*: Axes (:class:`matplotlib.axes` object)
 
     - *positions*: Positions (along the x axis)
 
@@ -362,7 +365,7 @@ def delayed_exit(message="Exiting...", t=0.5):
     >>> delayed_exit() # doctest: +SKIP
     Exiting...
     """
-    print("Exiting...")
+    print(message)
     time.sleep(t)
     exit()
 
@@ -422,7 +425,7 @@ def basename(fname):
     return os.path.splitext(os.path.basename(fname))[0]
 
 def multiglob(pathnames, extensions={'*.mat'}):
-    """Return a set of filenames that match a pathname pattern.
+    r"""Return a set of filenames that match a pathname pattern.
 
     Unlike Python's :meth:`glob.glob` function, this function runs an additional
     expansion on matches that are directories.
@@ -719,12 +722,13 @@ def load_csv(fname, header_row=0, first_data_row=None, types=None, **kwargs):
         next(reader)
     keys = next(reader)
     data = dict.fromkeys(keys)
-    #print("The keys are: ")
-    #print(keys)
+    # print("The keys are: ")
+    # print(keys)
 
     # Read the data.
     if first_data_row:
-        for row in range(first_data_row - header_row - 1):
+        # pylint: disable=W0612
+        for __ in range(first_data_row - header_row - 1):
             next(reader)
     if types:
         for i, (key, column, t) in enumerate(zip(keys, zip(*reader), types)):
@@ -807,7 +811,7 @@ def match(strings, pattern=None, re=False):
         return list(strings) # Shortcut
     else:
         if re:
-            matcher = re_compile(pattern).search
+            matcher = regexp.compile(pattern).search
         else:
             matcher = lambda name: fnmatchcase(name, pattern)
         return list(filter(matcher, strings))
@@ -988,7 +992,7 @@ def replace(fnames, rpls):
 
     # Compile the regular expressions.
     for i, (old, new) in enumerate(rpls):
-        rpls[i] = (re.compile(old), new)
+        rpls[i] = (regexp.compile(old), new)
 
     # Read each file and make the replacements.
     for fname in flatten_list(fnames):
@@ -1020,7 +1024,7 @@ def save(formats=['pdf', 'png'], fname=None, fig=None):
 
     - *fname*: Filename (see above)
 
-    - *fig*: `matplotlib <http://matplotlib.org/api/figure_api.html>`_ figure
+    - *fig*: `matplotlib figure <http://matplotlib.org/api/figure_api.html>`_
       or list of figures to be saved
 
            If *fig* is *None* (default), then the current figure will be saved.
@@ -1242,7 +1246,7 @@ def setup_subplots(n_plots, n_rows, title="", subtitles=None,
     for i in range(n_plots):
         # Create the axes.
         i_col = np.mod(i, n_cols)
-        #i_row = (i - i_col)/n_cols
+        # i_row = (i - i_col)/n_cols
         a = fig.add_subplot(n_rows, n_cols, i+1)
         ax.append(a)
 
@@ -1273,18 +1277,18 @@ def setup_subplots(n_plots, n_rows, title="", subtitles=None,
     # Add the colorbar.
     if ctype:
         if ctype == 'vertical':
-            #fig.subplots_adjust(left=left, bottom=top, right=1-cbar,
-            #                    top=1-top, hspace=hspace, vspace=vspace)
+            # fig.subplots_adjust(left=left, bottom=top, right=1-cbar,
+            #                     top=1-top, hspace=hspace, vspace=vspace)
             cax = fig.add_axes([1 - cbar + cbar_space, bottom,
                                 cbar_width, 1 - bottom - top])
-            #cax.set_ylabel(clabel)
+            # cax.set_ylabel(clabel)
         else:
-            #fig.subplots_adjust(left=left, bottom=cbar, right=1-left,
-            #                    top=1-top, hspace=hspace, vspace=vspace)
+            # fig.subplots_adjust(left=left, bottom=cbar, right=1-left,
+            #                     top=1-top, hspace=hspace, vspace=vspace)
             cax = fig.add_axes([left,
                                 cbar - cbar_space - cbar_width,
                                 1 - left - right, cbar_width])
-            #cax.set_xlabel(clabel)
+            # cax.set_xlabel(clabel)
         cax.set_ylabel(clabel)
         return ax, cax, n_cols
     else:
@@ -1441,7 +1445,7 @@ def tree(strings, separator='.'):
         branch = root
         elements = string.split(separator)
         for element in elements[:-1]:
-            if not element in branch:
+            if element not in branch:
                 branch[element] = {}
             branch = branch[element]
         branch[elements[-1]] = string
@@ -1451,7 +1455,7 @@ def tree(strings, separator='.'):
 # From http://old.nabble.com/Arrows-using-Line2D-and-shortening-lines-td19104579.html,
 # accessed 2010/11/2012
 class ArrowLine(Line2D):
-    """A matplotlib_ subclass to draw an arrowhead on a line
+    r"""A matplotlib_ subclass to draw an arrowhead on a line
 
     **Arguments:**
 
@@ -1484,6 +1488,8 @@ class ArrowLine(Line2D):
 
     from matplotlib.path import Path
 
+    # pylint: disable=E1101
+
     arrows = {'>' : '_draw_triangle_arrow'}
     _arrow_path = Path([[0.0, 0.0], [-1.0, 1.0], [-1.0, -1.0], [0.0, 0.0]],
                        [Path.MOVETO, Path.LINETO, Path.LINETO, Path.CLOSEPOLY])
@@ -1505,8 +1511,8 @@ class ArrowLine(Line2D):
     def draw(self, renderer):
         """Draw the line and arrowhead using the passed renderer.
         """
-        #if self._invalid:
-        #    self.recache()
+        # if self._invalid:
+        #     self.recache()
         renderer.open_group('arrowline2d')
         if not self._visible:
             return
@@ -1561,7 +1567,7 @@ class ArrowLine(Line2D):
 # Getch classes based on
 # http://code.activestate.com/recipes/134892-getch-like-unbuffered-character-reading-from-stdin/,
 # accessed 5/31/14
-class _Getch:
+class _Getch(object):
     """Get a single character from the standard input.
     """
     def __init__(self):
@@ -1573,12 +1579,16 @@ class _Getch:
     def __call__(self):
         return self.impl()
 
-class _GetchUnix:
+class _GetchUnix(object):
+    """Get a single character from the standard input on Unix.
+    """
     def __init__(self):
-        import tty, sys
+        # pylint: disable=W0611, W0612
+        import tty
 
     def __call__(self):
-        import sys, tty, termios
+        import tty
+        import termios
         fd = sys.stdin.fileno()
         old_settings = termios.tcgetattr(fd)
         try:
@@ -1588,8 +1598,11 @@ class _GetchUnix:
             termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
         return ch
 
-class _GetchWindows:
+class _GetchWindows(object):
+    """Get a single character from the standard input on Windows.
+    """
     def __init__(self):
+        # pylint: disable=W0611, W0612
         import msvcrt
 
     def __call__(self):
